<?php

/*Settings class */
class mob_Setting{
    /**
     * Holds the values to be used in the fields callbacks
     */
    private $options;

    public function __construct($mob_data)
    {
		$this->mob_data=$mob_data;

        add_action( 'admin_menu', array( $this, 'add_options_page' ) );
        add_action( 'admin_init', array( $this, 'register_options' ) );
    }
    /**
     * Add a new item in options menu to access the options page
     */
    public function add_options_page()
    {
        // This page will be under "Settings"
        add_options_page(
            'Settings Admin', 
            'mobile.de Import Einstellungen', 
            'manage_options', 
            'searchde-setting-admin', /* Page ID */
            array( $this, 'create_options_page' )
        );
    }
   /**
     * Options page callback that create all the fields used in settings
     */
    public function create_options_page()
    {
        // Set class property
        $this->options = get_option( 'MobileDE_option' );//option name
		if(empty( $this->options['mob_download_interval'])){
			 $this->options['mob_download_interval']='daily';
		}
        ?>
        <div class="wrap">
            <?php screen_icon(); ?>
            <h2><?php __('MobileDE Settings'); ?></h2>           
            <form class="inputForm" method="post" action="options.php">
            <?php
                // This prints out all hidden setting fields
                settings_fields( 'MobileDE_option' );   
                do_settings_sections( 'searchde-setting-admin' );
                submit_button(); 
				
				
            ?><input class="button-primary" type="button" id="importData" value="Fahrzeuge importieren"/>
			<input class="button-primary" type="button" id="deletePosts" value="Fahrzeuge löschen" />
            </form>
        </div>
        <?php
    }

   /**
     * Register all fields used in settings
     */
   
    public function register_options()
    { 
        register_setting(
            'MobileDE_option', // Option group
            'MobileDE_option', // Option name
            array( $this, 'sanitize' ) // Sanitize
        );
		add_settings_section(
            'connection_section_id', // Section ID
            'Verbindungseinstellungen', // Title
            array( $this, 'print_section_info' ), // Callback
            'searchde-setting-admin' // Page ID
        );
        add_settings_field(
            'mob_url', // ID
            'Mobile.de API URL', // Title 
            array( $this, 'mob_url_callback' ), // Callback
            'searchde-setting-admin', // Page
            'connection_section_id' // Section           
        );
		add_settings_field(
            'mob_username', 
            'Benutzername', 
            array( $this, 'mob_username_callback' ), 
            'searchde-setting-admin', 
            'connection_section_id'
        );
		add_settings_field(
            'mob_password', 
            'Passwort', 
            array( $this, 'mob_password_callback' ), 
            'searchde-setting-admin', 
            'connection_section_id'         
        );
        add_settings_field(
            'mob_language', 
            'Sprache', 
            array( $this, 'mob_language_callback' ), 
            'searchde-setting-admin', 
            'connection_section_id'
        );
        add_settings_field(
            'mob_download_interval', 
            'Import Intervall', 
            array( $this, 'mob_download_interval_callback' ), 
            'searchde-setting-admin', 
            'connection_section_id'
        );
        /*
        add_settings_field(
            'mob_styles', 
            'Apply Style', 
            array( $this, 'mob_styles_callback' ), 
            'searchde-setting-admin', 
            'connection_section_id'
        );
        */
		add_settings_section(
            'search_section_id', 
            'Suchkriterien', 
            array( $this, 'print_search_section_info' ), 
            'searchde-setting-admin' 
        );

		//register AJAX handlers
		add_action( 'wp_ajax_ajaxGetBrand', 'mob_ajaxGetBrand' );
		add_action( 'wp_ajax_ajaxGetCategory', 'mob_ajaxGetCategory' );
		add_action( 'wp_ajax_ajaxGetModel', 'mob_ajaxGetModel' );
		add_action( 'wp_ajax_ajaxGetFeatures', 'mob_ajaxGetFeatures' );
		add_action( 'wp_ajax_ajaxImportData', 'mob_ajaxImportData' );
		add_action( 'wp_ajax_ajaxDeletePosts', 'mob_ajaxDeletePosts' );

		
		
		//Some ajax. code to populate drop-down lists with proper values
		function mob_ajaxGetBrand(){
			global $wpdb, // this is how you get access to the database
				$mob_api;

			echo mob_htmlToOptions($mob_api->getBrands($_GET['id']));
			die();
		}
		function mob_ajaxGetCategory(){
			global $wpdb, // this is how you get access to the database
				$mob_api;

			echo mob_htmlToOptions($mob_api->getCategories($_GET['id']));
			die();
		}
		function mob_ajaxGetModel(){
			global $wpdb, // this is how you get access to the database
				$mob_api;

			list($class, $brand) = explode(':',$_GET['id']);
			echo mob_htmlToOptions($mob_api->getModels($class, $brand));
			die();
		}
		function mob_ajaxGetFeatures(){
			global $wpdb, // this is how you get access to the database
				$mob_api;

			echo mob_htmlToOptions($mob_api->getFeatures());
			die();
		}
		function mob_ajaxImportData(){
			
			$error=mob_download_import_feed();

			if(empty($error)) {
				die('1');
			}else {
				die($error);
			}
		}
		function mob_ajaxDeletePosts(){
			mob_deleteAllPosts();
			die('1');
		}
	}
	   /**
		 * Sanitize each setting field as needed
		 *
		 * @param array $input Contains all settings fields as array keys
		 */
		public function sanitize( $data )
		{
			$new_data = array();

			if(!empty($data['mob_url'])){
				$new_data['mob_url']=sanitize_text_field($data['mob_url']);
			}

			if(!empty($data['mob_username'])){
				for($i=0;$i<count($data['mob_username']);$i++) {
					if(!empty($data['mob_username'][$i])){
						$new_data['mob_username'][$i]=sanitize_text_field(trim($data['mob_username'][$i]));
						$new_data['mob_password'][$i]=sanitize_text_field(trim($data['mob_password'][$i]));
					}
				}
			}

			if(!empty($data['mob_language'])){
				$new_data['mob_language']=sanitize_text_field($data['mob_language']);
			}
			if(!empty($data['mob_download_interval'])){
				$new_data['mob_download_interval']=sanitize_text_field($data['mob_download_interval']);
				
				$this->options = get_option( 'MobileDE_option' );

				//update the interval of scheduler
				if($new_data['mob_download_interval'] != $this->options['mob_download_interval']) {
					mob_update_schedule($new_data['mob_download_interval']);
				}
			}
			/*
				if(!empty($data['mob_style'])){
				$new_data['mob_style']=sanitize_text_field($data['mob_style']);
			}
			*/
			//add search per classes, brand, models, variant (model description)
			if(!empty($data['class'])){
				$new_data['class']=sanitize_text_field($data['class']);

				if(!empty($data['brand'])){
					$new_data['brand']=sanitize_text_field($data['brand']);

					if(!empty($data['model'])){
						$new_data['model']=sanitize_text_field($data['model']);
					}

					if(!empty($data['variant'])){
						$new_data['variant']=sanitize_text_field($data['variant']);
					}
				}
			}
				if(!empty($data['category'])){
				$new_data['category']=sanitize_text_field(trim($data['category']));
			}
			if(!empty($data['firstRegistrationDateMin'])){
				$new_data['firstRegistrationDateMin']=sanitize_text_field(trim($data['firstRegistrationDateMin']));
			}
			if(!empty($data['firstRegistrationDateMax'])){
				$new_data['firstRegistrationDateMax']=sanitize_text_field(trim($data['firstRegistrationDateMax']));
			}

			if(!empty($data['owners'])){
				$new_data['owners']=sanitize_text_field($data['owners']);
			}
			if(!empty($data['mileageFrom'])){
				$new_data['mileageFrom']=sanitize_text_field(trim($data['mileageFrom']));
			}
			if(!empty($data['mileageTo'])){
				$new_data['mileageTo']=sanitize_text_field(trim($data['mileageTo']));
			}
			if(!empty($data['monthsTillInspection'])){
				$new_data['monthsTillInspection']=sanitize_text_field($data['monthsTillInspection']);
			}
			if(!empty($data['powerMin'])){
				$new_data['powerMin']=sanitize_text_field(trim($data['powerMin']));
			}
			if(!empty($data['powerMax'])){
				$new_data['powerMax']=sanitize_text_field(trim($data['powerMax']));
			}
			if(!empty($data['cubicCapacityMin'])){
				$new_data['cubicCapacityMin']=sanitize_text_field($data['cubicCapacityMin']);
			}
			if(!empty($data['cubicCapacityMax'])){
				$new_data['cubicCapacityMax']=sanitize_text_field($data['cubicCapacityMax']);
			}
			if(!empty($data['priceMin'])){
				$new_data['priceMin']=sanitize_text_field($data['priceMin']);
			}
			if(!empty($data['priceMax'])){
				$new_data['priceMax']=sanitize_text_field($data['priceMax']);
			}
			if(!empty($data['vatable'])){
				$new_data['vatable']=$data['vatable'];
			}
			if(!empty($data['fuel'])){
				$new_data['fuel']=implode(',',$data['fuel']);
			}
			if(!empty($data['gearbox'])){
				$new_data['gearbox']=sanitize_text_field($data['gearbox']);
			}
			if(!empty($data['damageUnrepaired'])){
				$new_data['damageUnrepaired']=$data['damageUnrepaired'];
			}
			if(!empty($data['roadworthy'])){
				$new_data['roadworthy']=$data['roadworthy'];
			}
			if(!empty($data['ambitCountry'])){
				$new_data['ambitCountry']=sanitize_text_field($data['ambitCountry']);
			}
			if($data['ambitCountry']=='DE' && !empty($data['ambitZipcode'])){
				$new_data['ambitZipcode']=sanitize_text_field($data['ambitZipcode']);
			}

			$new_data['enableNew']=sanitize_text_field(trim($data['enableNew']));

			if(!empty($data['enableNewDays'])){
				$new_data['enableNewDays']=sanitize_text_field(trim($data['enableNewDays']));
			}

			return $new_data;
		}

		//Print the Section text
		public function print_section_info()
		{
		}

		public function mob_url_callback()
		{
			printf(
				'<input type="text" id="mob_url" name="MobileDE_option[mob_url]" value="%s" />',
				isset( $this->options['mob_url'] ) ? esc_attr( $this->options['mob_url']) : ''
			);
		}

		public function mob_username_callback()
		{
			printf(
				'<input type="text" id="mob_username0" name="MobileDE_option[mob_username][0]" value="%s" />',
				isset( $this->options['mob_username'][0] ) ? esc_attr( $this->options['mob_username'][0]) : ''
			);
?>
			<input class="button-primary" type="button" id="addAccount" value="+ Add Account"/>
<?php
		}

		public function mob_password_callback()
		{
			printf(
				'<input type="password" class="mob_password" id="mob_password0" name="MobileDE_option[mob_password][0]" value="%s" />',
				isset( $this->options['mob_password'][0] ) ? esc_attr( $this->options['mob_password'][0]) : ''
			);
			for($i=1;$i<count($this->options['mob_username']);$i++) {
				echo '<tr valign="top"><th colspan="2" scope="row"><hr /></th>';

				echo '<tr valign="top"><th scope="row">Benutzername</th><td>';
				printf(
					'<input type="text" id="mob_username'.$i.'" name="MobileDE_option[mob_username]['.$i.']" value="%s" />',
					isset( $this->options['mob_username'][$i] ) ? esc_attr( $this->options['mob_username'][$i]) : ''
				);
				echo '</td></tr>';
				echo '<tr valign="top"><th scope="row">Passwort</th><td>';

				printf(
					'<input type="password" id="mob_password'.$i.'" name="MobileDE_option[mob_password]['.$i.']" value="%s" />',
					isset( $this->options['mob_password'][$i] ) ? esc_attr( $this->options['mob_password'][$i]) : ''
				);
				echo '</td></tr>';

			}
			echo '<tr valign="top"><th colspan="2" scope="row"><hr /></th>';
		}

		public function mob_language_callback()
		{
			echo '<select class="settingsSelect" name="MobileDE_option[mob_language]">'.
				mob_htmlToOptions($this->mob_data['languages'], false,
				isset( $this->options['mob_language'] ) ? esc_attr( $this->options['mob_language']) : ''.
				'</select>'
			);
		}
		
		public function mob_download_interval_callback()
		{
			echo '<select class="settingsSelect" name="MobileDE_option[mob_download_interval]">'.
				mob_htmlToOptions($this->mob_data['download_interval'], false,
				isset( $this->options['mob_download_interval'] ) ? esc_attr( $this->options['mob_download_interval']) : ''.
				'</select>'
			);
		}
		/*
			public function mob_styles_callback()
		{
			echo '<select class="settingsSelect" name="MobileDE_option[mob_style]">'.
				mob_htmlToOptions($this->mob_data['styles'], true,
				isset( $this->options['mob_style'] ) ? esc_attr( $this->options['mob_style']) : ''.
				'</select>'
			);
		}
		*/
		public function print_search_section_info() {
			global $mob_api;

			$classes=$mob_api->getClasses();
			$gearboxes=$mob_api->getGearboxes();
			$fuels=$mob_api->getFuels();
			$airbags=$mob_api->getAirbags();
		
			include 'template/admin_search_criteria.php';
		}
		public function print_widget_section_info() {
			global $mob_api;
		}

}
$mob_page = new mob_setting($mob_data);

